@@ -1,13 +1,13 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhrcfile.pl 2.12 99/09/28 23:12:20
+##	@(#) mhrcfile.pl 1.14 97/06/06 19:24:30 @(#)
 ##  Author:
-##      Earl Hood       mhonarc@pobox.com
+##      Earl Hood       ehood@medusa.acs.uci.edu
 ##  Description:
 ##      Routines for parsing resource files
 ##---------------------------------------------------------------------------##
 ##    MHonArc -- Internet mail-to-HTML converter
-##    Copyright (C) 1996-1999	Earl Hood, mhonarc@pobox.com
+##    Copyright (C) 1996,1997	Earl Hood, ehood@medusa.acs.uci.edu
 ##
 ##    This program is free software; you can redistribute it and/or modify
 ##    it under the terms of the GNU General Public License as published by
@@ -25,42 +25,35 @@
 ##    02111-1307, USA
 ##---------------------------------------------------------------------------##
 
-package mhonarc;
-
 ##---------------------------------------------------------------------------
 ##	read_resource_file() parses the resource file.
 ##	(The code for this routine could probably be simplified).
 ##
 sub read_resource_file {
-    my($file) = shift;
-    my($line, $tag, $label, $acro, $hr, $type, $routine, $plfile,
-       $url, $arg, $tmp, @a);
-    my($elem, $attr, $override, $handle, $pathhead, $chop);
-    $override = 0;
+    local($file) = shift;
+    local($line, $tag, $label, $acro, $hr, $type, $routine, $plfile,
+	  $url, $arg, $tmp, @a);
+    local($elem, $attr, $override, $handle, $pathhead, $chop);
 
-    $handle = &file_open($file);
-
-    if ($file =~ m%(.*[$DIRSEPREX])%o) {
+    if (!($handle = &file_open($file))) {
+	warn "Warning: Unable to open resource file: $file\n";
+	return 0;
+    }
+    if ($file =~ m%(.*[$'DIRSEPREX])%o) {
 	$pathhead = $1;
     } else {
 	$pathhead = '';
     }
 
     print STDOUT "Reading resource file: $file ...\n"  unless $QUIET;
-    while (defined($line = <$handle>)) {
+    while ($line = <$handle>) {
 	next unless $line =~ /^\s*<([^>]+)>/;
-	$attr = '';
 	($elem, $attr) = split(' ', $1, 2);
-	$attr = ''  unless defined($attr);
 	$elem =~ tr/A-Z/a-z/;
 	$override = ($attr =~ /override/i);
 	$chop = ($attr =~ /chop/i);
 
       FMTSW: {
-	if ($elem eq "addressmodifycode") {	# Code to strip subjects
-	    $AddressModify = &get_elem_content($handle, $elem, $chop);
-	    last FMTSW;
-	}
 	if ($elem eq "authorbegin") {		# Begin for author group
 	    $AUTHBEG = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
@@ -79,37 +72,22 @@ sub read_resource_file {
 	    last FMTSW;
 	}
 	if ($elem eq "charsetconverters") {	# Charset filters
-	    if ($override) {
-		%readmail::MIMECharSetConverters = ();
-		%readmail::MIMECharSetConvertersSrc = ();
-	    }
-	    while (defined($line = <$handle>)) {
+	    @CharSetRequires = (), %'MIMECharSetConverters = ()
+		if $override;
+	    while ($line = <$handle>) {
 		last  if $line =~ /^\s*<\/charsetconverters\s*>/i;
 		next  if $line =~ /^\s*$/;
 		$line =~ s/\s//g;
-		if ($line =~ /;/) {	# using Perl 5 qualification
-		    ($type,$routine,$plfile) = split(/;/,$line,3);
-		} else {
-		    ($type,$routine,$plfile) = split(/:/,$line,3);
-		}
+		($type,$routine,$plfile) = split(/:/,$line,3);
 		$type =~ tr/A-Z/a-z/;
-		$readmail::MIMECharSetConverters{$type}    = $routine;
-		$readmail::MIMECharSetConvertersSrc{$type} = $plfile
-		    if defined($plfile) and $plfile =~ /\S/;
+		$'MIMECharSetConverters{$type} = $routine;
+		push(@CharSetRequires, $plfile)  if $plfile =~ /\S/;
 	    }
 	    last FMTSW;
 	}
-	if ($elem eq "checknoarchive") {
-	    $CheckNoArchive = 1; last FMTSW;
-	}
 	if ($elem eq "conlen") {
 	    $CONLEN = 1; last FMTSW;
 	}
-	if ($elem eq "datefields") {
-	    @a = &get_list_content($handle, $elem);
-	    if (@a) { @DateFields = @a; }
-	    last FMTSW;
-	}
 	if ($elem eq "daybegin") {		# Begin for day group
 	    $DAYBEG = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
@@ -155,7 +133,7 @@ sub read_resource_file {
 	}
 	if ($elem eq "excs") {			# Exclude header fields
 	    %HFieldsExc = ()  if $override;
-	    while (defined($line = <$handle>)) {
+	    while ($line = <$handle>) {
 		last  if $line =~ /^\s*<\/excs\s*>/i;
 		$line =~ s/\s//g;  $line =~ tr/A-Z/a-z/;
 		$HFieldsExc{$line} = 1  if $line;
@@ -175,7 +153,7 @@ sub read_resource_file {
 	    last FMTSW;
 	}
 	if ($elem eq "fieldstyles") {		# Field text style
-	    while (defined($line = <$handle>)) {
+	    while ($line = <$handle>) {
 		last  if $line =~ /^\s*<\/fieldstyles\s*>/i;
 		next  if $line =~ /^\s*$/;
 		$line =~ s/\s//g;  $line =~ tr/A-Z/a-z/;
@@ -186,7 +164,7 @@ sub read_resource_file {
 	}
 	if ($elem eq "fieldorder") {		# Field order
 	    @FieldOrder = ();  %FieldODefs = ();
-	    while (defined($line = <$handle>)) {
+	    while ($line = <$handle>) {
 		last  if $line =~ /^\s*<\/fieldorder\s*>/i;
 		next  if $line =~ /^\s*$/;
 		$line =~ s/\s//g;  $line =~ tr/A-Z/a-z/;
@@ -212,18 +190,18 @@ sub read_resource_file {
 	    $FLDEND = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
-	if ($elem eq "folrefs") {		# Print explicit fol/refs
+	if ($elem eq "folrefs") {
 	    $DoFolRefs = 1; last FMTSW;
 	}
-	if ($elem eq "folupbegin") {		# Begin markup for follow-ups
+	if ($elem eq "folupbegin") {
 	    $FOLUPBEGIN = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
-	if ($elem eq "folupend") {		# End markup for follow-ups
+	if ($elem eq "folupend") {
 	    $FOLUPEND = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
-	if ($elem eq "foluplitxt") {		# Follow-up link markup
+	if ($elem eq "foluplitxt") {
 	    $FOLUPLITXT = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
@@ -234,11 +212,6 @@ sub read_resource_file {
 	    }
 	    last FMTSW;
 	}
-	if ($elem eq "fromfields") {		# Fields to get author
-	    @a = &get_list_content($handle, $elem);
-	    if (@a) { @FromFields = @a; }
-	    last FMTSW;
-	}
 	if ($elem eq "gmtdatefmt") {		# GMT date format
 	    if ($line = &get_elem_last_line($handle, $elem)) {
 		$GMTDateFmt = $line;
@@ -278,7 +251,7 @@ sub read_resource_file {
 	}
 	if ($elem eq "icons") {			# Icons
 	    %Icons = ()  if $override;
-	    while (defined($line = <$handle>)) {
+	    while ($line = <$handle>) {
 		last  if $line =~ /^\s*<\/icons\s*>/i;
 		next  if $line =~ /^\s*$/;
 		$line =~ s/\s//g;
@@ -321,11 +294,11 @@ sub read_resource_file {
 	    last FMTSW;
 	}
 	if ($elem eq "include") {		# Include other rc files
-	    while (defined($line = <$handle>)) {
+	    while ($line = <$handle>) {
 		last  if $line =~ /^\s*<\/include\s*>/i;
 		next  if $line =~ /^\s*$/;
 		$line =~ s/\s+$//;
-		$line = $pathhead . $line  if ($line !~ /$DIRSEPREX/o);
+		$line = $pathhead . $line  if ($line !~ /$'DIRSEPREX/o);
 		&read_resource_file($line);
 	    }
 	    last FMTSW;
@@ -339,7 +312,7 @@ sub read_resource_file {
 	    last FMTSW;
 	}
 	if ($elem eq "labelstyles") {		# Field label style
-	    while (defined($line = <$handle>)) {
+	    while ($line = <$handle>) {
 		last  if $line =~ /^\s*<\/labelstyles\s*>/i;
 		next  if $line =~ /^\s*$/;
 		$line =~ s/\s//g;  $line =~ tr/A-Z/a-z/;
@@ -366,17 +339,11 @@ sub read_resource_file {
 	    }
 	    last FMTSW;
 	}
-	if ($elem eq "lockmethod") {		# Locking method
-	    if ($line = &get_elem_last_line($handle, $elem)) {
-		$LockMethod = &set_lock_mode($line);
-	    }
-	    last FMTSW;
-	}
 	if ($elem eq "mailto") {		# Convert e-mail addrs
 	    $NOMAILTO = 0; last FMTSW;
 	}
 	if ($elem eq "mailtourl") {		# mailto URL
-	    while (defined($line = <$handle>)) {
+	    while ($line = <$handle>) {
 		last  if $line =~ /^\s*<\/mailtourl\s*>/i;
 		next  if $line =~ /^\s*$/;
 		$line =~ s/\s//g;
@@ -384,7 +351,7 @@ sub read_resource_file {
 	    }
 	    last FMTSW;
 	}
-	if ($elem eq "main") {			# Print main index
+	if ($elem eq "main") {
 	    $MAIN = 1; last FMTSW;
 	}
 	if ($elem eq "maxsize") {		# Size of archive
@@ -393,17 +360,10 @@ sub read_resource_file {
 	    }
 	    last FMTSW;
 	}
-	if ($elem eq "msgbodyend") {		# Markup after message body
+	if ($elem eq "msgbodyend") {
 	    $MSGBODYEND = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
-	if ($elem eq "msgexcfilter") {		# Code selectively exclude msgs
-	    $MsgExcFilter = &get_elem_content($handle, $elem, $chop);
-	    last FMTSW;
-	}
-	if ($elem eq "msgpgs") {		# Output message pages
-	    $NoMsgPgs = 0; last FMTSW;
-	}
 	if ($elem eq "msgprefix") {		# Prefix for message files
 	    if ($line = &get_elem_last_line($handle, $elem)) {
 		$line =~ s/\s//g;
@@ -417,59 +377,27 @@ sub read_resource_file {
 	    }
 	    last FMTSW;
 	}
-	if ($elem eq "mimedecoders") {		# Mime decoders
-	    if ($override) {
-		%readmail::MIMEDecoders = ();
-		%readmail::MIMEDecodersSrc = ();
-	    }
-	    while (defined($line = <$handle>)) {
-		last  if     $line =~ /^\s*<\/mimedecoders\s*>/i;
-		next  unless $line =~ /\S/;
-		$line =~ s/\s//g;
-		if ($line =~ /;/) {	# using Perl 5 qualification
-		    ($type,$routine,$plfile) = split(/;/,$line,3);
-		} else {
-		    ($type,$routine,$plfile) = split(/:/,$line,3);
-		}
-		$type =~ tr/A-Z/a-z/;
-		$readmail::MIMEDecoders{$type}    = $routine;
-		$readmail::MIMEDecodersSrc{$type} = $plfile  if $plfile =~ /\S/;
-	    }
-	    last FMTSW;
-	}
 	if ($elem eq "mimefilters") {		# Mime filters
-	    if ($override) {
-		%readmail::MIMEFilters = ();
-		%readmail::MIMEFiltersSrc = ();
-	    }
-	    while (defined($line = <$handle>)) {
+	    @Requires = (), %'MIMEFilters = ()  if $override;
+	    while ($line = <$handle>) {
 		last  if $line =~ /^\s*<\/mimefilters\s*>/i;
 		next  if $line =~ /^\s*$/;
 		$line =~ s/\s//g;
-		if ($line =~ /;/) {	# using Perl 5 qualification
-		    ($type,$routine,$plfile) = split(/;/,$line,3);
-		} else {
-		    ($type,$routine,$plfile) = split(/:/,$line,3);
-		}
+		($type,$routine,$plfile) = split(/:/,$line,3);
 		$type =~ tr/A-Z/a-z/;
-		$readmail::MIMEFilters{$type}    = $routine;
-		$readmail::MIMEFiltersSrc{$type} = $plfile  if $plfile =~ /\S/;
+		$'MIMEFilters{$type} = $routine;
+		push(@Requires, $plfile)  if $plfile =~ /\S/;
 	    }
 	    last FMTSW;
 	}
 	if ($elem eq "mimeargs") {		# Mime arguments
-	    %readmail::MIMEFiltersArgs = ()  if $override;
-	    while (defined($line = <$handle>)) {
-		last  if     $line =~ /^\s*<\/mimeargs\s*>/i;
-		next  unless $line =~ /\S/;
-		$line =~ s/^\s+//;
-		if ($line =~ /;/) {	# using Perl 5 qualification
-		    ($type, $arg) = split(/;/,$line,2);
-		} else {
-		    ($type, $arg) = split(/:/,$line,2);
-		}
+	    %'MIMEFiltersArgs = ()  if $override;
+	    while ($line = <$handle>) {
+		last  if $line =~ /^\s*<\/mimeargs\s*>/i;
+		next  if $line =~ /^\s*$/;
+		($type,$arg) = split(/:/,$line,2);
 		$type =~ tr/A-Z/a-z/  if $type =~ m%/%;
-		$readmail::MIMEFiltersArgs{$type} = $arg;
+		$'MIMEFiltersArgs{$type} = $arg;
 	    }
 	    last FMTSW;
 	}
@@ -504,10 +432,6 @@ sub read_resource_file {
 	    $MSGHEAD = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
-	if ($elem eq "msgidlink") {
-	    $MSGIDLINK = &get_elem_content($handle, $elem, $chop);
-	    last FMTSW;
-	}
 	if ($elem eq "msglocaldatefmt") {	# Message local date format
 	    if ($line = &get_elem_last_line($handle, $elem)) {
 		$MsgLocalDateFmt = $line;
@@ -528,7 +452,7 @@ sub read_resource_file {
 	    }
 	    last FMTSW;
 	}
-	if ($elem eq "multipg") {		# Print multi-page indexes
+	if ($elem eq "multipg") {
 	    $MULTIIDX = 1; last FMTSW;
 	}
 	if ($elem eq "nextbutton") {		# Next button link in message
@@ -562,25 +486,22 @@ sub read_resource_file {
 	    $AUTHSORT = 0;
 	    last FMTSW;
 	}
-	if ($elem eq "nochecknoarchive") {
-	    $CheckNoArchive = 0; last FMTSW;
-	}
 	if ($elem eq "noconlen") {		# Ignore content-length
 	    $CONLEN = 0; last FMTSW;
 	}
-	if ($elem eq "nodecodeheads") {		# Don't decode charsets
+	if ($elem eq "nodecodeheads") {
 	    $DecodeHeads = 0; last FMTSW;
 	}
 	if ($elem eq "nodoc") {			# Do not link to docs
 	    $NODOC = 1; last FMTSW;
 	}
-	if ($elem eq "nofolrefs") {		# Don't print explicit fol/refs
+	if ($elem eq "nofolrefs") {
 	    $DoFolRefs = 0; last FMTSW;
 	}
-	if ($elem eq "nogzipfiles") {		# Don't gzip files
+	if ($elem eq "nogzipfiles") {
 	    $GzipFiles = 0;  last FMTSW;
 	}
-	if ($elem eq "nogziplinks") {		# Don't add ".gz" to links
+	if ($elem eq "nogziplinks") {
 	    $GzipLinks = 0;  last FMTSW;
 	}
 	if ($elem eq "nomailto") {		# Do not convert e-mail addrs
@@ -592,107 +513,47 @@ sub read_resource_file {
 	if ($elem eq "nomodtime") {		# Do not change mod times
 	    $MODTIME = 0; last FMTSW;
 	}
-	if ($elem eq "nomsgpgs") {		# Do not print message pages
-	    $NoMsgPgs = 1; last FMTSW;
-	}
 	if ($elem eq "nomultipg") {		# Single page index
 	    $MULTIIDX = 0; last FMTSW;
 	}
 	if ($elem eq "nonews") {		# Ignore news for linking
 	    $NONEWS = 1; last FMTSW;
 	}
-	if ($elem eq "noposixstrftime") {	# Do not use POSIX::strftime()
-	    $POSIXstrftime = 0;
-	    last FMTSW;
-	}
 	if ($elem eq "noreverse") {		# Sort in normal order
 	    $REVSORT = 0; last FMTSW;
 	}
-	if ($elem eq "nosaveresources") {	# Do not save resources
-	    $SaveRsrcs = 0;
-	    last FMTSW;
-	}
 	if ($elem eq "nosort") {		# Do not sort messages
 	    $NOSORT = 1;
 	    last FMTSW;
 	}
-	if ($elem eq "nospammode") {		# Do not do anti-spam stuff
-	    $SpamMode = 0; last FMTSW;
-	}
-	if ($elem eq "nosubjectthreads") {	# No check subjects for threads
-	    $NoSubjectThreads = 1;
-	    last FMTSW;
-	}
 	if ($elem eq "nosubsort") {		# Do not sort msgs by subject
 	    $SUBSORT = 0;
 	    last FMTSW;
 	}
-	if ($elem eq "note") {			# Annotation markup
-	    $NOTE = &get_elem_content($handle, $elem, $chop);
-	    last FMTSW;
-	}
-	if ($elem eq "notedir") {		# Notes directory
-	    if ($line = &get_elem_last_line($handle, $elem)) {
-		$NoteDir = $line;
-	    }
-	    last FMTSW;
-	}
-	if ($elem eq "noteia") {		# No Annotation markup
-	    $NOTEIA = &get_elem_content($handle, $elem, $chop);
-	    last FMTSW;
-	}
-	if ($elem eq "noteicon") {		# Note icon
-	    $NOTEICON = &get_elem_content($handle, $elem, $chop);
-	    last FMTSW;
-	}
-	if ($elem eq "noteiconia") {		# Note icon when no annotation
-	    $NOTEICONIA = &get_elem_content($handle, $elem, $chop);
-	    last FMTSW;
-	}
 	if ($elem eq "nothread") {		# No thread index
 	    $THREAD = 0; last FMTSW;
 	}
 	if ($elem eq "notreverse") {		# Thread sort in normal order
 	    $TREVERSE = 0; last FMTSW;
 	}
-	if ($elem eq 'notsubsort' ||
-	    $elem eq "tnosubsort") {		# No subject order for threads
-	    $TSUBSORT = 0;
-	    last FMTSW;
-	}
-	if ($elem eq 'notsort' ||
-	    $elem eq "tnosort") {		# Raw order for threads
-	    $TNOSORT = 1; $TSUBSORT = 0;
-	    last FMTSW;
-	}
 	if ($elem eq "nourl") {			# Ignore URLs
 	    $NOURL = 1; last FMTSW;
 	}
-	if ($elem eq "nouselocaltime") {	# Not using localtime
-	    $UseLocalTime = 0; last FMTSW;
-	}
-	if ($elem eq "nousinglastpg") {		# Not using $LASTPG$
-	    $UsingLASTPG = 0; last FMTSW;
-	}
 	if ($elem eq "otherindexes") {		# Other indexes
 	    @OtherIdxs = ()  if $override;
-	    unshift(@OtherIdxs, &get_pathname_content($handle, $elem));
+	    unshift(@OtherIdxs, &get_list_content($handle, $elem, $'PATHSEP));
 	    last FMTSW;
 	}
 	if ($elem eq "perlinc") {		# Define perl search paths
 	    @PerlINC = ()  if $override;
-	    unshift(@PerlINC, &get_pathname_content($handle, $elem));
-	    last FMTSW;
-	}
-	if ($elem eq "posixstrftime") {		# Use POSIX::strftime()
-	    $POSIXstrftime = 1;
+	    unshift(@PerlINC, &get_list_content($handle, $elem, $'PATHSEP));
 	    last FMTSW;
 	}
 	if ($elem eq "prevbutton") {		# Prev button link in message
 	    $PREVBUTTON = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
-	if ($elem eq "prevbuttonia") {		# Prev i/a button link
+	if ($elem eq "prevbuttonia") {
 	    $PREVBUTTONIA = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
@@ -700,7 +561,7 @@ sub read_resource_file {
 	    $PREVLINK = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
-	if ($elem eq "prevlinkia") {		# Prev i/a link
+	if ($elem eq "prevlinkia") {
 	    $PREVLINKIA = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
@@ -712,15 +573,15 @@ sub read_resource_file {
 	    $PREVPGLINKIA = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
-	if ($elem eq "refsbegin") {		# Explicit ref links begin
+	if ($elem eq "refsbegin") {
 	    $REFSBEGIN = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
-	if ($elem eq "refsend") {		# Explicit ref links end
+	if ($elem eq "refsend") {
 	    $REFSEND = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
-	if ($elem eq "refslitxt") {		# Explicit ref link
+	if ($elem eq "refslitxt") {
 	    $REFSLITXT = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
@@ -728,42 +589,11 @@ sub read_resource_file {
 	    $REVSORT = 1;
 	    last FMTSW;
 	}
-	if ($elem eq "saveresources") {		# Save resources in db
-	    $SaveRsrcs = 1;
-	    last FMTSW;
-	}
 	if ($elem eq "sort") {			# Sort messages by date
 	    $NOSORT = 0;
 	    $AUTHSORT = 0;  $SUBSORT = 0;
 	    last FMTSW;
 	}
-	if ($elem eq "spammode") {		# Obfsucate/hide addresses
-	    $SpamMode = 1; last FMTSW;
-	}
-	if ($elem eq "ssmarkup") {		# Initial page markup
-	    $SSMARKUP = &get_elem_content($handle, $elem, $chop);
-	    last FMTSW;
-	}
-	if ($elem eq "subjectarticlerxp") {	# Regex for language articles
-	    if ($line = &get_elem_last_line($handle, $elem)) {
-		$SubArtRxp = $line;
-	    }
-	    last FMTSW;
-	}
-	if ($elem eq "subjectreplyrxp") {	# Regex for reply text
-	    if ($line = &get_elem_last_line($handle, $elem)) {
-		$SubReplyRxp = $line;
-	    }
-	    last FMTSW;
-	}
-	if ($elem eq "subjectstripcode") {	# Code to strip subjects
-	    $SubStripCode = &get_elem_content($handle, $elem, $chop);
-	    last FMTSW;
-	}
-	if ($elem eq "subjectthreads") {	# Check subjects for threads
-	    $NoSubjectThreads = 0;
-	    last FMTSW;
-	}
 	if ($elem eq "subsort") {		# Sort messages by subject
 	    $SUBSORT = 1;
 	    $AUTHSORT = 0;  $NOSORT = 0;
@@ -824,13 +654,12 @@ sub read_resource_file {
 	    last FMTSW;
 	}
 	if ($elem eq "timezones") {		# Time zones
-	    if ($override) { %ZoneUD = (); }
-	    while (defined($line = <$handle>)) {
+	    %Zone = ()  if $override;
+	    while ($line = <$handle>) {
 		last  if $line =~ /^\s*<\/timezones\s*>/i;
 		$line =~ s/\s//g;  $line =~ tr/a-z/A-Z/;
 		($acro,$hr) = split(/:/,$line);
-		$acro =~ tr/a-z/A-Z/;
-		$ZoneUD{$acro} = $hr;
+		$Zone{$acro} = $hr;
 	    }
 	    last FMTSW;
 	}
@@ -872,17 +701,12 @@ sub read_resource_file {
 	    $TOPLINKS = &get_elem_content($handle, $elem, $chop);
 	    last FMTSW;
 	}
-	if ($elem eq "tslice") {
-	    ($TSliceNBefore, $TSliceNAfter) =
-		&get_list_content($handle, $elem);
+	if ($elem eq "tnosubsort") {		# No subject order for threads
+	    $TSUBSORT = 0;
 	    last FMTSW;
 	}
-	if ($elem eq "tslicebeg") {		# Start of thread slice
-	    $TSLICEBEG = &get_elem_content($handle, $elem, $chop);
-	    last FMTSW;
-	}
-	if ($elem eq "tsliceend") {		# End of thread slice
-	    $TSLICEEND = &get_elem_content($handle, $elem, $chop);
+	if ($elem eq "tnosort") {		# Raw order for threads
+	    $TNOSORT = 1; $TSUBSORT = 0;
 	    last FMTSW;
 	}
 	if ($elem eq "tsort") {			# Date order for threads
@@ -986,12 +810,6 @@ sub read_resource_file {
 	    }
 	    last FMTSW;
 	}
-	if ($elem eq "uselocaltime") {		# Use localtime for day groups
-	    $UseLocalTime = 1; last FMTSW;
-	}
-	if ($elem eq "usinglastpg") {
-	    $UsingLASTPG = 1; last FMTSW;
-	}
 	if ($elem eq "weekdays") {		# Full weekday name
 	    @a = &get_list_content($handle, $elem);
 	    if (scalar(@a)) {
@@ -1015,7 +833,7 @@ sub read_resource_file {
 
 ##----------------------------------------------------------------------
 sub get_elem_content {
-    local($filehandle, $gi, $chop) = @_;
+    local($filehandle, $gi, $chop) = ($_[0], $_[1], $_[2]);
     local($ret) = '';
 
     while (<$filehandle>) {
@@ -1028,7 +846,7 @@ sub get_elem_content {
 
 ##----------------------------------------------------------------------
 sub get_elem_int {
-    local($filehandle, $gi, $abs) = @_;
+    local($filehandle, $gi, $abs) = ($_[0], $_[1], $_[2]);
     local($ret) = '';
 
     while (<$filehandle>) {
@@ -1043,7 +861,7 @@ sub get_elem_int {
 
 ##----------------------------------------------------------------------
 sub get_elem_last_line {
-    local($filehandle, $gi) = @_;
+    local($filehandle, $gi) = ($_[0], $_[1]);
     local($ret) = '';
 
     while (<$filehandle>) {
@@ -1057,28 +875,15 @@ sub get_elem_last_line {
 
 ##----------------------------------------------------------------------
 sub get_list_content {
-    local($filehandle, $gi) = @_;
+    local($filehandle, $gi, $sep) = ($_[0], $_[1], $_[2]);
     local(@items) = ();
+    $sep = ':'  unless $sep;
 
     while (<$filehandle>) {
 	last  if /^\s*<\/$gi\s*>/i;
 	next  unless /\S/;
 	s/\r?\n?$//;
-	push(@items, split(/[:]/, $_));
-    }
-    @items;
-}
-
-##----------------------------------------------------------------------
-sub get_pathname_content {
-    local($filehandle, $gi) = @_;
-    local(@items) = ();
-
-    while (<$filehandle>) {
-	last  if /^\s*<\/$gi\s*>/i;
-	next  unless /\S/;
-	s/\r?\n?$//;
-	push(@items, split(/$PATHSEP/o, $_));
+	push(@items, split(/$sep/, $_));
     }
     @items;
 }
